exceptiontools.LilyPondParserError
==================================

.. abjad-lineage:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError

.. autoclass:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__unicode__
   :noindex:
